@@ -528,34 +528,41 @@ sub config_to_package_id {
 =cut
 
 sub init_hs_env {
+    my %params = (
+        parse_cabal => 1,
+        @_
+    );
+
     $ENV{DEB_DEFAULT_COMPILER} //= 'ghc';
 
     $ENV{DEB_GHC_DATABASE} = 'debian/tmp-db';
 
-    my @cabal_candidates = glob('*.cabal');
+    if ($params{parse_cabal}) {
+        my @cabal_candidates = glob('*.cabal');
 
-    error('No cabal file found')
-      unless @cabal_candidates;
+        die encode_utf8('No cabal file found')
+            unless @cabal_candidates;
 
-    error('More than one cabal file')
-      if @cabal_candidates > 1;
+        die encode_utf8('More than one cabal file')
+            if @cabal_candidates > 1;
 
-    my $cabal_path = $cabal_candidates[0];
-    my $cabal_contents = path($cabal_path)->slurp_utf8;
+        my $cabal_path = $cabal_candidates[0];
+        my $cabal_contents = path($cabal_path)->slurp_utf8;
 
-    error('Cannot get package name from cabal file')
-      unless $cabal_contents =~ /^ name \s* : \s* (\S*) \s* $/imx;
+        die encode_utf8('Cannot get package name from cabal file')
+            unless $cabal_contents =~ /^ name \s* : \s* (\S*) \s* $/imx;
 
-    my $package_name = lc $1;
+        my $package_name = lc $1;
 
-    $ENV{CABAL_PACKAGE} //= $package_name;
+        $ENV{CABAL_PACKAGE} //= $package_name;
 
-    error('Cannot get package version from cabal file')
-      unless $cabal_contents =~ /^ version \s* : \s* (\S*) \s* $/imx;
+        die encode_utf8('Cannot get package version from cabal file')
+            unless $cabal_contents =~ /^ version \s* : \s* (\S*) \s* $/imx;
 
-    my $package_version = $1;
+        my $package_version = $1;
 
-    $ENV{CABAL_VERSION} = $package_version;
+        $ENV{CABAL_VERSION} = $package_version;
+    }
 
     $ENV{DEB_ENABLE_TESTS} //= 'no';
     $ENV{DEB_ENABLE_HOOGLE} //= 'yes';
